<script>
import AppLayout from "@/Layouts/AppLayout.vue";
import Toast from "@/Componentes/Toastify/Toast.vue";
import ItemFolder from "@/Pages/Explorer/ItemFolder.vue";
import ItemFile from "@/Pages/Explorer/ItemFile.vue";
import Cache from "@/Store/Cache.js";
import {MasterMethods} from "@/Store/Functions.js";

export default {
    name: "Index",
    components: {ItemFile, ItemFolder, Toast, AppLayout},
    created() {
        console.clear()
        this.totalSizeCalculate();
    },
    data() {
        return {
            store: new Cache(),
            breadcrumb: new Cache(),
            content: {
                name: null,
                items: []
            },
            totalSize: this.formatBytes(0)
        };
    },
    watch:{
        "$page.props.content": {
            handler(newValue, oldValue){
                let name = newValue?.name;
                if(name === "root"){
                    name = this.$page.props.site.displayName;
                }
                if(this.store.containsKey(name)){
                    this.store.update(name, newValue?.items);
                }else {
                    this.store.add(name, newValue?.items)
                    this.content = this.$page.props.content
                }

                if(this.breadcrumb.containsKey(name)){
                    this.breadcrumb.update(name, null);
                }else {
                    this.breadcrumb.add(name, null)
                }
            },
            immediate: true
        },
        "content.items": function () {
            this.totalSizeCalculate();
        }
    },
    methods: {
        ...MasterMethods,
        getCacheSite(key){
            if(this.store.containsKey(key)){
                let data = this.store.tryGetValue(key);
                this.content = {
                    name: key,
                    items: data.value
                };
                let del = false;
                for(let item of this.breadcrumb.keys()){
                    if(del){
                        this.breadcrumb.remove(item);
                        this.store.remove(item);
                    }
                    if(item === key){
                        del = true;
                    }
                }
            }
        },
        totalSizeCalculate(){
            let i = 0;
           try{
               for(let item of this.content?.items){
                   i += item.size;
               }
           }catch (e) {
               console.clear()
           }
            this.totalSize = this.formatBytes(i);
        }
    }
}
</script>

<template>
    <AppLayout title="Explorador">
        <Toast />
        <div class="container-fluid">
            <div class="card card-primary card-outline rounded-0">
                <div class="card-header py-2">
                    <span class="text-xs" v-for="(item, n) in breadcrumb.keys()">
                        <span v-if="n > 0" class="fa fa-chevron-right mx-2"></span>
                        <span class="text-cyan-400" v-if="(n+1) === breadcrumb.keys().length">{{item}}</span>
                        <span  @click="getCacheSite(item)" class="cursor-pointer" v-else>{{item}}</span>
                    </span>
                </div>
                <div class="card-body py-0">
                    <div class="row">
                        <div class="col-sm-12 col-md-4 border-r-2 p-0">
                            <ul class="list-group border-0 overflow-x-scroll h-40 md:h-96">
                                <ItemFolder v-for="item in content?.items" :item="item" :slug="$page.props.site.slug" />
                            </ul>
                        </div>

                        <div class="col-sm-12 col-md-8 p-0">
                            <div class="table-responsive h-96">
                                <table class="table table-borderless">
                                    <thead class="bg-gray-200 border-b border-b-gray-300 text-xs">
                                    <tr>
                                        <th class="py-0">Nombre</th>
                                        <th class="py-0">Tamaño</th>
                                        <th class="py-0">Tipo</th>
                                        <th class="py-0"></th>
                                    </tr>
                                    </thead>
                                    <tbody>
                                    <ItemFile v-for="item in content?.items" :item="item" />
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="card-footer border-t-2 py-1 text-xs font-bold">
                    <span class="float-start">{{ (content?.items)? content?.items?.length : 0 }} elementos</span>
                    <span class="float-end">{{ totalSize }}</span>
                </div>
            </div>
        </div>
    </AppLayout>
</template>

<style scoped>
.breadcrumb {
    --bs-breadcrumb-divider: '>' !important;
}
</style>
